@@ -12,8 +12,7 @@
 
 =head1 NAME
 
-Bio::Tools::Run::Alignment::Lagan - Object for the local execution of the LAGAN suite
-of tools (including MLAGAN for multiple sequence alignments)
+Bio::Tools::Run::Alignment::Lagan - Object for the local execution of the LAGAN suite of tools (including MLAGAN for multiple sequence alignments)
 
 =head1 SYNOPSIS
 
@@ -47,9 +46,12 @@ of tools (including MLAGAN for multiple sequence alignments)
 
 =head1 DESCRIPTION
 
-To run mlagan/lagan, the executables "mlagan" and "lagan.pl" must be
-in your path or you must have an environment variable that points to
-the executable directory "LAGANDIR=/opt/lagan_executables/"
+To run mlagan/lagan, you must have an environment variable that points to
+the executable directory with files lagan.pl etc.
+"LAGAN_DIR=/opt/lagan_executables/"
+
+Simply having the executables in your path is not supported because the
+executables themselves only work with the environment variable set.
 
 All lagan and mlagan parameters listed in their Readmes can be set
 except for the mfa flag which has been turned on by default to prevent
@@ -89,17 +91,16 @@ Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bugzilla.bioperl.org/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Stephen Montgomery
 
@@ -120,7 +121,7 @@ Internal methods are usually preceded with a _
 
 package Bio::Tools::Run::Alignment::Lagan;
 
-use vars qw(@ISA $PROGRAM_DIR @LAGAN_PARAMS @MLAGAN_PARAMS @LAGAN_SWITCHES
+use vars qw(@ISA $PROGRAM_DIR @LAGAN_PARAMS @MLAGAN_PARAMS @LAGAN_SWITCHES @OTHER_PARAMS
 	    %OK_FIELD $AUTOLOAD);
 
 use strict;
@@ -132,6 +133,7 @@ use Bio::AlignIO;
 use Bio::AlignIO::fasta;
 use Bio::SimpleAlign;
 use Bio::Tools::Run::WrapperBase;
+use Cwd;
 
 @ISA = qw(	Bio::Root::Root
 		Bio::Tools::Run::WrapperBase);
@@ -140,6 +142,7 @@ BEGIN {
 
     @LAGAN_PARAMS = qw(chaos order recurse mfa out lazy maskedonly
                        usebounds rc translate draft info fastreject);
+    @OTHER_PARAMS = qw(outfile);
     @LAGAN_SWITCHES = qw(silent quiet);
     @MLAGAN_PARAMS = qw(nested postir translate lazy verbose tree match mismatch
                         gapstart gapend gapcont out version);
@@ -148,28 +151,27 @@ BEGIN {
     #should be used in setting only standard ones
 
     #Authorize Attribute fields
-    foreach my $attr (@LAGAN_PARAMS, @LAGAN_SWITCHES, @MLAGAN_PARAMS) {
+    foreach my $attr (@LAGAN_PARAMS, @LAGAN_SWITCHES, @MLAGAN_PARAMS,@OTHER_PARAMS) {
         $OK_FIELD{$attr}++;
     }
 
-    #The LAGANDIR environment variable should be set if the lagan
-    #executables aren't in your path.
-    $PROGRAM_DIR = $ENV{'LAGANDIR'} || '';
+    #The LAGAN_DIR environment variable must be set
+    $PROGRAM_DIR = $ENV{'LAGAN_DIR'} || '';
 }
 
 sub new {
     my($class, @args) = @_;
     my $self = $class->SUPER::new(@args);
-
-    my ($tfh, $tempfile) = $self->io->tempfile();
-    close($tfh);
-    undef $tfh;
-    $self->out($tempfile);
     while (@args) {
         my $attr = shift @args;
         my $value = shift @args;
         $self->$attr($value);
     }
+    my ($tfh, $tempfile) = $self->io->tempfile();
+    my $outfile = $self->out || $self->outfile || $tempfile;
+    $self->out($outfile);
+    close($tfh);
+    undef $tfh;
     return $self;
 }
 
@@ -200,7 +202,6 @@ sub lagan {
 		
     #my (undef, $tempfile) = $self->io->tempfile();
     #$self->out($tempfile);
-
     my ($infile1, $infile2) = $self->_setinput($executable, $input1, $input2);
     my $lagan_report = &_generic_lagan(	$self,
                                         $executable,
@@ -220,7 +221,8 @@ sub mlagan {
     my ($self, $input1, $tree) = @_;
     $self->io->_io_cleanup();
     my $executable = 'mlagan';
-    my ($infiles, $tree) = $self->_setinput($executable, $input1, $tree);
+    my $infiles;
+    ($infiles, $tree) = $self->_setinput($executable, $input1, $tree);
     my $lagan_report = &_generic_lagan (	$self,
 						$executable,
 						$infiles,
@@ -375,10 +377,9 @@ sub _runlagan {
     my ($self, $executable, $param_string, $input1, $input2) = @_;
     my ($lagan_obj, $exe);
     if ( ! ($exe = $self->executable($executable))) {
-        $self->warn("cannot find path to $executable");
-        return undef;
+        return;
     }
-
+    
     my $command_string;
     if ($executable eq 'lagan.pl') {
         $command_string = $exe . " " . $input1 . " " . $input2 . $param_string;
@@ -392,19 +393,37 @@ sub _runlagan {
             $command_string .= " -tree " . "\"" . $input2 . "\"";
         }	
         $command_string .= " " . $param_string;
-        print $command_string;
     }
 
     if (($self->silent ||  $self->quiet) &&
         ($^O !~ /os2|dos|MSWin32|amigaos/)) {
-      $command_string .= ' 2> /dev/null';
+      $command_string .= ' > /dev/null 2> /dev/null';
 
     }
     
+    # will do brute-force clean up of junk files generated by lagan
+    my $cwd = cwd();
+    opendir(my $cwd_dir, $cwd) || $self->throw("Could not open the current directory '$cwd'!");
+    my %ok_files;
+    foreach my $thing (readdir($cwd_dir)) {
+        if ($thing =~ /anch/) {
+            $ok_files{$thing} = 1;
+        }
+    }
+    closedir($cwd_dir);
+    
     $self->debug("$command_string\n");
-    my $status = system($command_string);
+    my $status = system('_POSIX2_VERSION=1 '.$command_string); # temporary hack whilst lagan script 'rechaos.pl' uses obsolete sort syntax
+    
+    opendir($cwd_dir, $cwd) || $self->throw("Could not open the current directory '$cwd'!");
+    foreach my $thing (readdir($cwd_dir)) {
+        if ($thing =~ /anch/) {
+            unlink($thing) unless $ok_files{$thing};
+        }
+    }
+    closedir($cwd_dir);
+    
     my $outfile = $self->out();
-	
     my $align = Bio::AlignIO->new(	'-file' => $outfile,
 					'-format' => 'fasta' );
     my $aln = $align->next_aln();
@@ -436,8 +455,8 @@ sub executable {
     unless ( defined $self->{'_pathtoexe'}->{$exename} ) {
         my $f = $self->program_path($exename);
         $exe = $self->{'_pathtoexe'}->{$exename} = $f if(-e $f && -x $f );
-
-        unless( $exe )  { 
+        
+        unless( $exe )  {
             if ( ($exe = $self->io->exists_exe($exename)) && -x $exe ) {
                 $self->{'_pathtoexe'}->{$exename} = $exe;
             } else {
@@ -446,6 +465,14 @@ sub executable {
             }
         }
     }
+    
+    # even if its executable, we still need the environment variable to have
+    # been set
+    if (! $PROGRAM_DIR) {
+        $self->warn("Environment variable LAGAN_DIR must be set, even if the lagan executables are in your path");
+        $self->{'_pathtoexe'}->{$exename} = undef;
+    }
+    
     return $self->{'_pathtoexe'}->{$exename};
 }
 
