@@ -1,4 +1,4 @@
-# $Id$
+# $Id: Pise.pm,v 1.9 2006/07/04 22:23:32 mauricio Exp $
 # BioPerl modules for Pise
 #
 # Cared for by Catherine Letondal <letondal@pasteur.fr>
@@ -64,7 +64,7 @@ You can either set location at:
 
 =over 3
 
-=item 1 factory creation
+=item 1 factory creation:
 
   my $factory = Bio::Tools::Run::AnalysisFactory::Pise->new(
                                  -location => 'http://somewhere/Pise/cgi-bin',
@@ -103,17 +103,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to
 the Bioperl mailing list.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org              - General discussion
-  http://bioperl.org/MailList.shtml  - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
-of the bugs and their resolution. Bug reports can be submitted via
-email or the web:
+of the bugs and their resolution. Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bioperl.org
-  http://bioperl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR
 
