@@ -31,7 +31,7 @@ program Consense
   my @params = ('datatype'=>'SEQUENCE','replicates'=>10);
   my $seqboot_factory = Bio::Tools::Run::Phylo::Phylip::SeqBoot->new(@params);
 
-  my $aln_ref= $seqboot->run($aln);
+  my $aln_ref= $seqboot_factory->run($aln);
 
   #next build distance matrices and construct trees
   my $pd_factory = Bio::Tools::Run::Phylo::Phylip::ProtDist->new();
@@ -148,17 +148,16 @@ User feedback is an integral part of the evolution of this and other
 Bioperl modules. Send your comments and suggestions preferably to one
 of the Bioperl mailing lists.  Your participation is much appreciated.
 
-  bioperl-l@bioperl.org          - General discussion
-  http://bio.perl.org/MailList.html             - About the mailing lists
+  bioperl-l@bioperl.org                  - General discussion
+  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
- the bugs and their resolution.  Bug reports can be submitted via
- email or the web:
+the bugs and their resolution.  Bug reports can be submitted via the
+web:
 
-  bioperl-bugs@bio.perl.org
-  http://bio.perl.org/bioperl-bugs/
+  http://bugzilla.open-bio.org/
 
 =head1 AUTHOR - Shawn Hoon 
 
@@ -183,7 +182,7 @@ use strict;
 use Bio::SimpleAlign;
 use Bio::TreeIO;
 use Bio::Tools::Run::Phylo::Phylip::Base;
-use Bio::Tools::Run::Phylo::Phylip::PhylipConf;
+use Bio::Tools::Run::Phylo::Phylip::PhylipConf qw(%Menu);
 use IO::String;
 use Cwd;
 
@@ -498,7 +497,7 @@ sub _setparams {
     #for case where type is Ml
     my $Ml = 0;
     my $frac = 0.5;
-    my %menu = %{%Bio::Tools::Run::Phylo::Phylip::PhylipConf::Menu->{$self->version}->{'CONSENSE'}};
+    my %menu = %{$Menu{$self->version}->{'CONSENSE'}};
 
     foreach  my $attr ( @CONSENSE_PARAMS) {
     	$value = $self->$attr();
@@ -601,7 +600,7 @@ sub _setparams {
 
  Title   : cleanup
  Usage   : $codeml->cleanup();
- Function: Will cleanup the tempdir directory after a PAML run
+ Function: Will cleanup the tempdir directory after a Consense run
  Returns : none
  Args    : none
 
